"""
===========================
Main (:mod:`macroeco.main`)
===========================

This module contains the functions that make up MacroecoDesktop.

.. autosummary::
   :toctree: generated/

   main

"""

from ._main import main
from ._gui import launch
